searchNodes=[{"doc":"This module contains data and functions for obtaining geographic data in compliance with the ISO-3166-2 standard.","ref":"ISO.html","title":"ISO","type":"module"},{"doc":"Returns a map of country codes and their full names. Takes in a list of optional atoms to tailor the results. For example, :with_subdivisions only includes countries with subdivisions.iex&gt; countries = ISO.countries() iex&gt; get_in(countries, [&quot;US&quot;, &quot;name&quot;]) &quot;United States of America (the)&quot; iex&gt; get_in(countries, [&quot;PR&quot;, &quot;name&quot;]) &quot;Puerto Rico&quot; iex&gt; countries = ISO.countries([:with_subdivisions]) iex&gt; countries[&quot;PR&quot;] nil iex&gt; countries = ISO.countries([:exclude_territories]) iex&gt; countries[&quot;PR&quot;] nil","ref":"ISO.html#countries/1","title":"ISO.countries/1","type":"function"},{"doc":"Converts a full country name to its 2-letter ISO-3166-2 code.iex&gt; ISO.country_code(&quot;United States&quot;) &quot;US&quot; iex&gt; ISO.country_code(&quot;UNITED STATES&quot;) &quot;US&quot; iex&gt; ISO.country_code(&quot;Mexico&quot;) &quot;MX&quot; iex&gt; ISO.country_code(&quot;Venezuela&quot;) &quot;VE&quot; iex&gt; ISO.country_code(&quot;Iran&quot;) &quot;IR&quot; iex&gt; ISO.country_code(&quot;Taiwan&quot;) &quot;TW&quot; iex&gt; ISO.country_code(&quot;Bolivia&quot;) &quot;BO&quot; iex&gt; ISO.country_code(&quot;Not a country.&quot;) nil","ref":"ISO.html#country_code/1","title":"ISO.country_code/1","type":"function"},{"doc":"Converts a country's 2-letter code to its full name.iex&gt; ISO.country_name(&quot;US&quot;) &quot;United States of America (the)&quot; iex&gt; ISO.country_name(&quot;US&quot;, :informal) &quot;United States of America&quot; iex&gt; ISO.country_name(&quot;US&quot;, :short_name) &quot;UNITED STATES OF AMERICA&quot; iex&gt; ISO.country_name(&quot;TN&quot;) &quot;Tunisia&quot; iex&gt; ISO.country_name(&quot;TX&quot;) nil","ref":"ISO.html#country_name/2","title":"ISO.country_name/2","type":"function"},{"doc":"Returns all ISO-3166-2 data.","ref":"ISO.html#data/0","title":"ISO.data/0","type":"function"},{"doc":"Finds the country data for the given country. May be an ISO-3166-compliant country code or a string to perform a search with. Return a tuple in the format {code, data} if a country was found; otherwise nil.iex&gt; {code, data} = ISO.find_country(&quot;United States&quot;) iex&gt; code &quot;US&quot; iex&gt; data |&gt; Map.get(&quot;short_name&quot;) &quot;UNITED STATES OF AMERICA&quot; iex&gt; {code, data} = ISO.find_country(&quot;US&quot;) iex&gt; code &quot;US&quot; iex&gt; data |&gt; Map.get(&quot;short_name&quot;) &quot;UNITED STATES OF AMERICA&quot; iex&gt; ISO.find_country(&quot;Invalid&quot;) nil","ref":"ISO.html#find_country/1","title":"ISO.find_country/1","type":"function"},{"doc":"Takes a country input and subdivision and returns the validated, ISO-3166-compliant subdivision code in a tuple.iex&gt; ISO.find_subdivision_code(&quot;US&quot;, &quot;TX&quot;) {:ok, &quot;US-TX&quot;} iex&gt; ISO.find_subdivision_code(&quot;US&quot;, &quot;US-TX&quot;) {:ok, &quot;US-TX&quot;} iex&gt; ISO.find_subdivision_code(&quot;US&quot;, &quot;Texas&quot;) {:ok, &quot;US-TX&quot;} iex&gt; ISO.find_subdivision_code(&quot;United States&quot;, &quot;Texas&quot;) {:ok, &quot;US-TX&quot;} iex&gt; ISO.find_subdivision_code(&quot;SomeCountry&quot;, &quot;SG-SG&quot;) {:error, &quot;Invalid country: SomeCountry&quot;} iex&gt; ISO.find_subdivision_code(&quot;SG&quot;, &quot;SG-Invalid&quot;) {:error, &quot;Invalid subdivision &#39;SG-Invalid&#39; for country: SG (SG)&quot;}","ref":"ISO.html#find_subdivision_code/2","title":"ISO.find_subdivision_code/2","type":"function"},{"doc":"Returns the subdivision data for the ISO-3166-compliant subdivision code.iex&gt; ISO.get_subdivision(&quot;US-TX&quot;) {:ok, %{&quot;category&quot; =&gt; &quot;state&quot;, &quot;name&quot; =&gt; &quot;Texas&quot;}} iex&gt; ISO.get_subdivision(&quot;MX-CMX&quot;) {:ok, %{&quot;category&quot; =&gt; &quot;federal district&quot;, &quot;name&quot; =&gt; &quot;Ciudad de México&quot;}} iex&gt; ISO.get_subdivision(&quot;11-SG&quot;) {:error, :not_found} iex&gt; ISO.get_subdivision(&quot;SG-Invalid&quot;) {:error, :not_found} iex&gt; ISO.get_subdivision(&quot;Invalid&quot;) {:error, :not_found}","ref":"ISO.html#get_subdivision/1","title":"ISO.get_subdivision/1","type":"function"},{"doc":"Converts a full subdivision name to its 2-letter ISO-3166-2 code. The country MUST be an ISO-compliant 2-letter country code.iex&gt; ISO.subdivision_code(&quot;US&quot;, &quot;Texas&quot;) &quot;US-TX&quot; iex&gt; ISO.subdivision_code(&quot;US&quot;, &quot;US-TX&quot;) &quot;US-TX&quot; iex&gt; ISO.subdivision_code(&quot;CA&quot;, &quot;AlberTa&quot;) &quot;CA-AB&quot; iex&gt; ISO.subdivision_code(&quot;MX&quot;, &quot;Yucatán&quot;) &quot;MX-YUC&quot; iex&gt; ISO.subdivision_code(&quot;MX&quot;, &quot;Yucatan&quot;) &quot;MX-YUC&quot; iex&gt; ISO.subdivision_code(&quot;IE&quot;, &quot;Co. Wicklow&quot;) &quot;IE-WW&quot; iex&gt; ISO.subdivision_code(&quot;MX&quot;, &quot;Not a subdivision.&quot;) nil","ref":"ISO.html#subdivision_code/2","title":"ISO.subdivision_code/2","type":"function"},{"doc":"Returns true if the country with the given code is a territory of another country. This only applies to subdivisions that have their own country code.iex&gt; ISO.territory?(&quot;PR&quot;) true iex&gt; ISO.territory?(&quot;US&quot;) false iex&gt; ISO.territory?(&quot;TX&quot;) false","ref":"ISO.html#territory?/1","title":"ISO.territory?/1","type":"function"},{"doc":"","ref":"ISO.html#t:country_code/0","title":"ISO.country_code/0","type":"type"},{"doc":"","ref":"ISO.Util.html","title":"ISO.Util","type":"module"},{"doc":"Removes accents/ligatures from letters.iex&gt; Util.unaccent(&quot;Curaçao&quot;) &quot;Curacao&quot; iex&gt; Util.unaccent(&quot;Republic of Foo (the)&quot;) &quot;Republic of Foo (the)&quot; iex&gt; Util.unaccent(&quot;Åland Islands&quot;) &quot;Aland Islands&quot;","ref":"ISO.Util.html#unaccent/1","title":"ISO.Util.unaccent/1","type":"function"}]